@@ -10,7 +10,8 @@
 #' @return an object of class "SDMXCompactData"
 #' 
 #' @seealso \link{readSDMX}
-#'
+#' @export
+#' 
 SDMXCompactData <- function(xmlObj, namespaces){
   new("SDMXCompactData",
       SDMXData(xmlObj, namespaces)
@@ -33,8 +34,7 @@ getSDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
   if(length(ns) > 1) ns <- ns[1]
   
   authorityNamespaces <- nsDefs.df[
-    regexpr("http://www.sdmx.org", nsDefs.df$uri,
-            "match.length", ignore.case = TRUE) == -1,]
+    attr(regexpr("http://www.sdmx.org", nsDefs.df$uri, ignore.case = TRUE), "match.length") == -1,]
   authorityNamespaces <- as.data.frame(authorityNamespaces, stringsAsFactors = FALSE)
   colnames(authorityNamespaces) <- "uri"
   
@@ -151,7 +151,7 @@ getSDMXAllCompactData <- function(x, nsExpr, labels = FALSE, ...) {
   return(encodeSDMXOutput(dataset))
 }
 
-
+#'@export
 as.data.frame.SDMXCompactData <- function(x, row.names=NULL, optional=FALSE,
                                           labels = FALSE, ...){
   return(getSDMXAllCompactData(x, nsExpr = "compact", labels = labels));
