@@ -28,6 +28,8 @@
 #'   provider <- SDMXServiceProvider(agencyId = "MYORG", name = "My Organization",
 #'                                   builder = myBuilder)
 #'                                   
+#' @export
+#'                                   
 SDMXServiceProvider <- function(agencyId, name,
                                 scale = "international", country = as.character(NA),
                                 builder) {
@@ -60,33 +62,47 @@ SDMXServiceProvider <- function(agencyId, name,
 #' 
 #' @seealso \link{getSDMXServiceProviders} \link{addSDMXServiceProvider}
 #'          \link{findSDMXServiceProvider} \link{readSDMX}
-#'
+#' @export
+#' 
 setSDMXServiceProviders <- function(){ # nocov start
     
   #international data providers
   #----------------------------
 
+  #BIS
+  BIS <- SDMXServiceProvider(
+   agencyId = "BIS", name = "Bank for International Settlements",
+   builder = SDMXREST21RequestBuilder(
+     regUrl = "https://stats.bis.org/api/v1",
+     repoUrl = "https://stats.bis.org/api/v1",
+     compliant = TRUE
+   )
+  )
+  
   #ECB
   ECB <- SDMXServiceProvider(
     agencyId = "ECB", name = "European Central Bank",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "https://sdw-wsrest.ecb.europa.eu/service",
-      repoUrl = "https://sdw-wsrest.ecb.europa.eu/service",
-      compliant = TRUE)
+      regUrl = "https://data-api.ecb.europa.eu/service",
+      repoUrl = "https://data-api.ecb.europa.eu/service",
+      skipTrailingSlash = TRUE,
+      compliant = TRUE
+    )
   )
-
+  
   #EUROSTAT
   ESTAT <- SDMXServiceProvider( 
     agencyId = "ESTAT", name = "Eurostat (Statistical office of the European Union)",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "http://ec.europa.eu/eurostat/SDMX/diss-web/rest",
-      repoUrl = "http://ec.europa.eu/eurostat/SDMX/diss-web/rest",
-      compliant = TRUE)
+      regUrl = "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1",
+      repoUrl = "https://ec.europa.eu/eurostat/api/dissemination/sdmx/2.1",
+      compliant = TRUE
+    )
   )
   ESTAT@builder@handler$dataflow = function(obj){
     if(is.null(obj@resourceId)) obj@resourceId = "all"
     if(is.null(obj@version)) obj@version = "latest"
-    req <- sprintf("%s/dataflow/ESTAT/%s/%s/",obj@regUrl, obj@resourceId, obj@version)        
+    req <- sprintf("%s/dataflow/ESTAT/%s/%s/",obj@regUrl, obj@resourceId, obj@version)
     return(req)
   }
   ESTAT@builder@handler$datastructure = function(obj){
@@ -97,21 +113,89 @@ setSDMXServiceProviders <- function(){ # nocov start
     return(req)
   }
   
+  #ESTAT_COMEXT
+  ESTAT_COMEXT <- SDMXServiceProvider( 
+    agencyId = "ESTAT", name = "Eurostat (Statistical office of the European Union) - COMEXT",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://ec.europa.eu/eurostat/api/comext/dissemination/sdmx/2.1",
+      repoUrl = "https://ec.europa.eu/eurostat/api/comext/dissemination/sdmx/2.1",
+      compliant = TRUE
+    )
+  )
+  ESTAT_COMEXT@builder@handler$dataflow = ESTAT@builder@handler$dataflow
+  ESTAT_COMEXT@builder@handler$datastructure = ESTAT@builder@handler$datastructure
+  
+  #ESTAT_GROW
+  ESTAT_GROW <- SDMXServiceProvider( 
+    agencyId = "ESTAT", name = "Eurostat (Statistical office of the European Union) - DG GROW",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://webgate.ec.europa.eu/grow/redisstat/api/dissemination/sdmx/2.1",
+      repoUrl = "https://webgate.ec.europa.eu/grow/redisstat/api/dissemination/sdmx/2.1",
+      compliant = TRUE
+    )
+  )
+  ESTAT_GROW@builder@handler$dataflow = ESTAT@builder@handler$dataflow
+  ESTAT_GROW@builder@handler$datastructure = ESTAT@builder@handler$datastructure
+  
+  #ESTAT_COMP
+  ESTAT_COMP <- SDMXServiceProvider( 
+    agencyId = "ESTAT", name = "Eurostat (Statistical office of the European Union) - DG COMP",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://webgate.ec.europa.eu/comp/redisstat/api/dissemination/sdmx/2.1",
+      repoUrl = "https://webgate.ec.europa.eu/comp/redisstat/api/dissemination/sdmx/2.1",
+      compliant = TRUE
+    )
+  )
+  ESTAT_COMP@builder@handler$dataflow = ESTAT@builder@handler$dataflow
+  ESTAT_COMP@builder@handler$datastructure = ESTAT@builder@handler$datastructure
+  
+  #ESTAT_EMPL
+  ESTAT_EMPL <- SDMXServiceProvider( 
+    agencyId = "ESTAT", name = "Eurostat (Statistical office of the European Union) - DG EMPL",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://webgate.ec.europa.eu/empl/redisstat/api/dissemination/sdmx/2.1",
+      repoUrl = "https://webgate.ec.europa.eu/empl/redisstat/api/dissemination/sdmx/2.1",
+      compliant = TRUE
+    )
+  )
+  ESTAT_EMPL@builder@handler$dataflow = ESTAT@builder@handler$dataflow
+  ESTAT_EMPL@builder@handler$datastructure = ESTAT@builder@handler$datastructure
+  
   #IMF
   IMF <- SDMXServiceProvider(
     agencyId = "IMF", name = "International Monetary Fund",
     builder = SDMXREST21RequestBuilder(
       regUrl = "https://sdmxcentral.imf.org/ws/public/sdmxapi/rest",
       repoUrl = "https://sdmxcentral.imf.org/ws/public/sdmxapi/rest",
-      compliant = TRUE)
+      compliant = TRUE,
+      unsupportedResources = list("data")
+    )
+  )
+
+  #IMF_DATA
+  IMF_DATA <- SDMXServiceProvider(
+    agencyId = "IMF_DATA", name = "International Monetary Fund - Data Portal",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://api.imf.org/external/sdmx/2.1",
+      repoUrl = "https://api.imf.org/external/sdmx/2.1",
+      compliant = TRUE,
+      formatter = list(
+        datastructure = function(obj){
+          if(is.null(obj@references)) obj@references = "descendants"
+          return(obj)
+        }
+      )
+    )
   )
     
   #OECD
   OECD <- SDMXServiceProvider(
     agencyId = "OECD", name = "Organisation for Economic Cooperation and Development ",
-    builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://stats.oecd.org/restsdmx/sdmx.ashx",
-      repoUrl = "http://stats.oecd.org/restsdmx/sdmx.ashx")
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://sdmx.oecd.org/public/rest",
+      repoUrl = "https://sdmx.oecd.org/public/rest",
+      compliant = TRUE
+    )
   )
   
   #UNICEF
@@ -124,6 +208,16 @@ setSDMXServiceProviders <- function(){ # nocov start
     )
   )
   
+  #COUNTDOWN 2030
+  CD2030 <- SDMXServiceProvider(
+    agencyId = "CD2030", "United Nations International Children's Emergency Fund",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://sdmx.data.unicef.org/ws/public/sdmxapi/rest",
+      repoUrl = "https://sdmx.data.unicef.org/ws/public/sdmxapi/rest",
+      compliant = TRUE
+    )
+  )
+  
   #UNSD
   UNSD <- SDMXServiceProvider(
     agencyId = "UNSD", "United Nations Statistics Division",
@@ -134,60 +228,37 @@ setSDMXServiceProviders <- function(){ # nocov start
     )
   )  
   
-  #UN-FAO
-  FAO <- SDMXServiceProvider(
-    agencyId = "FAO", name = "Food and Agriculture Organization of the United Nations",
-    builder = SDMXREST21RequestBuilder(
-      regUrl = "http://data.fao.org/sdmx/registry",
-      repoUrl = "http://data.fao.org/sdmx/repository",
-      compliant = FALSE,
-      unsupportedResources = list("dataflow"))
-  )
-  
   #UN-ILO (Legacy)
   ILO_Legacy <- SDMXServiceProvider(
     agencyId = "ILO_Legacy", name = "International Labour Organization of the United Nations",
     builder = SDMXREST21RequestBuilder(
       regUrl = "http://www.ilo.org/ilostat/sdmx/ws/rest",
       repoUrl = "http://www.ilo.org/ilostat/sdmx/ws/rest",
-      compliant = FALSE, skipProviderId = TRUE,
-      unsupportedResources = list("dataflow"))                  
+      compliant = FALSE,
+      skipProviderId = TRUE,
+      unsupportedResources = list("dataflow")
+    )                  
   )
   
   #UN-ILO
   ILO <- SDMXServiceProvider(
     agencyId = "ILO", name = "International Labour Organization of the United Nations",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "https://www.ilo.org/sdmx/rest",
-      repoUrl = "https://www.ilo.org/sdmx/rest",
-      compliant = TRUE, skipProviderId = TRUE)                  
-  )
-  
-  #UIS (UNESCO)
-  UIS <- SDMXServiceProvider(
-    agencyId = "UIS", name = "UNESCO Institute of Statistics (old - http://data.uis.unesco.org)",
-    builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://data.uis.unesco.org/RestSDMX/sdmx.ashx",
-      repoUrl = "http://data.uis.unesco.org/RestSDMX/sdmx.ashx")
-  )
-  
-  #UIS2 (UNESCO)
-  UIS2 <- SDMXServiceProvider(
-    agencyId = "UIS2", name = "UNESCO Institute of Statistics (new - http://api.uis.unesco.org)",
-    builder = SDMXREST21RequestBuilder(
-      regUrl = "http://api.uis.unesco.org/sdmx",
-      repoUrl = "http://api.uis.unesco.org/sdmx",
-      accessKey = "subscription-key",
-      compliant = TRUE, skipProviderId = TRUE)
+      regUrl = "https://sdmx.ilo.org/rest",
+      repoUrl = "https://sdmx.ilo.org/rest",
+      compliant = TRUE,
+      skipProviderId = TRUE
+    )                  
   )
   
   #WBG_WITS (World Integrated Trade Solution)
   WBG_WITS <- SDMXServiceProvider(
     agencyId = "WBG_WITS", name = "World Integrated Trade Solution",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "http://wits.worldbank.org/API/V1/SDMX/V21/rest",
-      repoUrl = "http://wits.worldbank.org/API/V1/SDMX/V21/rest",
-      compliant = TRUE, skipProviderId = TRUE
+      regUrl = "https://wits.worldbank.org/API/V1/SDMX/V21/rest",
+      repoUrl = "https://wits.worldbank.org/API/V1/SDMX/V21/rest",
+      compliant = TRUE,
+      skipProviderId = TRUE
     )
   )
   
@@ -197,17 +268,19 @@ setSDMXServiceProviders <- function(){ # nocov start
     builder = SDMXREST21RequestBuilder(
       regUrl = "http://api.worldbank.org/v2/sdmx/rest",
       repoUrl = "http://api.worldbank.org/v2/sdmx/rest",
-      compliant = TRUE, skipProviderId = TRUE
+      compliant = TRUE,
+      skipProviderId = TRUE
     )
   )
-
+  
   #PDH.STAT (Pacific Data Hub by The Pacific Community)
   PDH <- SDMXServiceProvider(
     agencyId = "PDH", name = "Pacific Data Hub DotStat",
     builder = SDMXREST21RequestBuilder(
       regUrl = "https://stats-nsi-stable.pacificdata.org/rest",
       repoUrl = "https://stats-nsi-stable.pacificdata.org/rest",
-      compliant = FALSE) 
+      compliant = FALSE
+    ) 
   )
   
   #national data providers
@@ -217,10 +290,11 @@ setSDMXServiceProviders <- function(){ # nocov start
   ABS <- SDMXServiceProvider(
     agencyId = "ABS", name = "Australian Bureau of Statistics",
     scale = "national", country = "AUS",
-    builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://stat.data.abs.gov.au/restsdmx/sdmx.ashx",
-      repoUrl = "http://stat.data.abs.gov.au/restsdmx/sdmx.ashx", 
-      forceProviderId = TRUE, unsupportedResources = list("dataflow"))
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "https://api.data.abs.gov.au",
+      repoUrl = "https://api.data.abs.gov.au",
+      compliant = TRUE
+    )
   )
   
   #NBB {Belgium}
@@ -228,9 +302,10 @@ setSDMXServiceProviders <- function(){ # nocov start
     agencyId = "NBB", name = "National Bank of Belgium",
     scale = "national", country = "BEL",
     builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://stat.nbb.be/RestSDMX/sdmx.ashx",
-      repoUrl = "http://stat.nbb.be/RestSDMX/sdmx.ashx", 
-      unsupportedResources = list("dataflow"))
+      regUrl = "https://stat.nbb.be/RestSDMX/sdmx.ashx",
+      repoUrl = "https://stat.nbb.be/RestSDMX/sdmx.ashx",
+      unsupportedResources = list("dataflow")
+    )
   )
   
   #INSEE {France}
@@ -239,8 +314,9 @@ setSDMXServiceProviders <- function(){ # nocov start
     scale = "national", country = "FRA",
     builder = SDMXREST21RequestBuilder(
       regUrl = "https://bdm.insee.fr/series/sdmx",
-      repoUrl = "https://bdm.insee.fr/series/sdmx", 
-      compliant = TRUE)
+      repoUrl = "https://bdm.insee.fr/series/sdmx",
+      compliant = TRUE
+    )
   )
   
   #INEGI (Mexico)
@@ -248,19 +324,30 @@ setSDMXServiceProviders <- function(){ # nocov start
     agencyId = "INEGI", name = "Instituto Nacional de Estad\u00edstica y Geograf\u00eda (M\u00e9jico)",
     scale = "national", country = "MEX",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "http://sdmx.snieg.mx/service/Rest",
-      repoUrl = "http://sdmx.snieg.mx/service/Rest",
+      regUrl = "https://sdmx.snieg.mx/ServiceV6/rest",
+      repoUrl = "https://sdmx.snieg.mx/ServiceV6/rest",
       compliant = FALSE
     )
   )
   
+  #ISTAT - LEGACY (Italy)
+  ISTAT_LEGACY <- SDMXServiceProvider(
+    agencyId = "ISTAT_LEGACY", name = "Istituto nazionale di statistica (Italia)",
+    scale = "national", country = "ITA",
+    builder = SDMXREST21RequestBuilder(
+      regUrl = "http://sdmx.istat.it/SDMXWS/rest",
+      repoUrl = "http://sdmx.istat.it/SDMXWS/rest",
+      compliant = TRUE
+    )
+  )
+  
   #ISTAT (Italy)
   ISTAT <- SDMXServiceProvider(
     agencyId = "ISTAT", name = "Istituto nazionale di statistica (Italia)",
     scale = "national", country = "ITA",
     builder = SDMXREST21RequestBuilder(
-      regUrl = "http://sdmx.istat.it/SDMXWS/rest",
-      repoUrl = "http://sdmx.istat.it/SDMXWS/rest",
+      regUrl = "https://esploradati.istat.it/SDMXWS/rest",
+      repoUrl = "https://esploradati.istat.it/SDMXWS/rest",
       compliant = TRUE
     )
   )
@@ -280,7 +367,7 @@ setSDMXServiceProviders <- function(){ # nocov start
       ),
       handler = list(
         
-        #'dataflow' resource (path="dataset/{resourceId}/def.sdmx.xml")
+        #dataflow resource (path="dataset/resourceId/def.sdmx.xml")
         #-----------------------------------------------------------------------
         dataflow = function(obj){  
           req <- sprintf("%s/dataset", obj@regUrl)
@@ -288,7 +375,7 @@ setSDMXServiceProviders <- function(){ # nocov start
           req <- paste(req, "def.sdmx.xml", sep="/")
           return(req)
         },
-        #'datastructure' resource (path="dataset/{resourceID}.structure.sdmx.xml")
+        #datastructure resource (path="dataset/resourceID.structure.sdmx.xml")
         #-----------------------------------------------------------------------
         datastructure = function(obj){
           req <- sprintf("%s/dataset", obj@regUrl)
@@ -297,7 +384,7 @@ setSDMXServiceProviders <- function(){ # nocov start
           req <- paste0(req, ".structure.sdmx.xml")
           return(req)
         },
-        #'data' resource (path="dataset/{resourceID}.generic.sdmx.xml")
+        #data resource (path="dataset/resourceID.generic.sdmx.xml")
         #----------------------------------------------------------
         data = function(obj){
           req <- sprintf("%s/dataset", obj@repoUrl)
@@ -336,18 +423,18 @@ setSDMXServiceProviders <- function(){ # nocov start
       ),
       handler = list(
         
-        #'dataflow' resource (path="/")
+        #dataflow resource (path="/")
         #-----------------------------------------------------------------------
         dataflow = function(obj){
           return(obj@regUrl)
         },
-        #'datastructure' resource (path="/{resourceID})
+        #datastructure resource (path="/resourceID)
         #-----------------------------------------------------------------------
         datastructure = function(obj){
           req <- paste(obj@regUrl, obj@resourceId, sep = "/")
           return(req)
         },
-        #'data' resource (path="getdata?dataflow={flowRef}&key={key})
+        #data resource (path="getdata?dataflow=flowRef&key=key)
         #----------------------------------------------------------
         data = function(obj){
           if(is.null(obj@flowRef)) stop("Missing flowRef value")
@@ -373,26 +460,79 @@ setSDMXServiceProviders <- function(){ # nocov start
     )
   )
   
-  #STAT_EE - Statistics Estonia database {Estonia}
-  STAT_EE <- SDMXServiceProvider(
-    agencyId = "STAT_EE", name = "Statistics Estonia database",
-    scale = "national", country = "EST",
-    builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://andmebaas.stat.ee/restsdmx/sdmx.ashx",
-      repoUrl = "http://andmebaas.stat.ee/restsdmx/sdmx.ashx",
-      unsupportedResources = list("dataflow")
+  #UKDS removed - no support for SDMX-JSON in rsdmx at now
+  #UKDS <- SDMXServiceProvider(
+  #  agencyId = "UKDS", name = "United Kingdom Data Service",
+  #  scale = "national", country = "UK",
+  #  builder = SDMXDotStatRequestBuilder(
+  #    regUrl = "http://stats.ukdataservice.ac.uk/restsdmx/sdmx.ashx",
+  #    repoUrl = "http://stats.ukdataservice.ac.uk/restsdmx/sdmx.ashx",
+  #    unsupportedResources = list("dataflow")
+  #  )
+  #)
+  
+  #Bundesbank
+  BBK <- SDMXServiceProvider(
+    agencyId = "BBK", name = "Bundesbank",
+    scale = "national", country = "DEU",
+    builder = SDMXRequestBuilder(
+      regUrl = "https://api.statistiken.bundesbank.de/rest/metadata",
+      repoUrl = "https://api.statistiken.bundesbank.de/rest",
+      formatter = list(
+        dataflow = function(obj){return(obj)},
+        datastructure = function(obj){return(obj)},
+        data = function(obj){return(obj)}
+      ),
+      #resource handler
+      handler = list(
+        
+        #dataflow resource (dataflow/agencyID/resourceID/version)
+        #-----------------------------------------------------------------------
+        dataflow = function(obj){
+          req <- sprintf("%s/dataflow/%s",obj@regUrl, obj@providerId)
+          if(!is.null(obj@resourceId)) req <- paste(req, obj@resourceId, sep = "/")
+          return(req)
+        },
+        
+        #datastructure resource (datastructure/agencyID/resourceID/version)
+        #--------------------------------------------------------------------------------
+        datastructure = function(obj){
+          req <- sprintf("%s/datastructure/%s",obj@regUrl, obj@providerId)
+          if(!is.null(obj@resourceId)) req <- paste(req, obj@resourceId, sep = "/")
+          req <- paste0(req, "?references=children") #TODO to see later to have arg for this
+          return(req)
+        },
+        
+        #data resource (data/flowRef/key/providerRef)
+        #----------------------------------------------------------
+        data = function(obj){
+          if(is.null(obj@flowRef)) stop("Missing flowRef value")
+          req <- sprintf("%s/data/%s/%s",obj@repoUrl, obj@flowRef, obj@key)
+          
+          #DataQuery
+          #-> temporal extent (if any)
+          addParams = FALSE
+          if(!is.null(obj@start)){
+            req <- paste0(req, "?")
+            addParams = TRUE
+            req <- paste0(req, "startPeriod=", obj@start)
+          }
+          if(!is.null(obj@end)){
+            if(!addParams){
+              req <- paste0(req, "?")
+            }else{
+              req <- paste0(req, "&")
+            }
+            req <- paste0(req, "endPeriod=", obj@end) 
+          }
+          
+          return(req)
+        }
+      ),
+      compliant = FALSE
     )
   )
   
-  UKDS <- SDMXServiceProvider(
-    agencyId = "UKDS", name = "United Kingdom Data Service",
-    scale = "national", country = "UK",
-    builder = SDMXDotStatRequestBuilder(
-      regUrl = "http://stats.ukdataservice.ac.uk/restsdmx/sdmx.ashx",
-      repoUrl = "http://stats.ukdataservice.ac.uk/restsdmx/sdmx.ashx",
-      unsupportedResources = list("dataflow")
-    )
-  )
   
   #other data providers
   #--------------------
@@ -410,18 +550,18 @@ setSDMXServiceProviders <- function(){ # nocov start
       ),
       handler = list(
                                   
-        #'dataflow' resource (path="/")
+        #dataflow resource (path="/")
         #-----------------------------------------------------------------------
         dataflow = function(obj){
           return(obj@regUrl)
         },
-        #'datastructure' resource (path="/{resourceID})
+        #datastructure resource (path="/resourceID)
         #-----------------------------------------------------------------------
         datastructure = function(obj){
           req <- paste(obj@regUrl, obj@resourceId, sep = "/")
           return(req)
         },
-        #'data' resource (path="getdata?dataflow={flowRef}&key={key})
+        #data resource (path="getdata?dataflow=flowRef&key=key)
         #----------------------------------------------------------
         data = function(obj){
           if(is.null(obj@flowRef)) stop("Missing flowRef value")
@@ -443,65 +583,13 @@ setSDMXServiceProviders <- function(){ # nocov start
     )
   )
   
-  #WIDUKIND project - International Economics Database
-  WIDUKIND <- SDMXServiceProvider(
-    agencyId = "WIDUKIND", name = "Widukind project - International Economics Database",
-    builder = SDMXREST21RequestBuilder(
-      regUrl = "http://widukind-api.cepremap.org/api/v1/sdmx",
-      repoUrl = "http://widukind-api.cepremap.org/api/v1/sdmx",
-      compliant = FALSE, skipProviderId = TRUE
-    )
-  )
-  WIDUKIND@builder@handler$dataflow = function(obj){
-    req <- sprintf("%s/dataflow",obj@regUrl)
-    if(!is.null(obj@agencyId)) req = paste(req, obj@agencyId,sep="/")
-    if(!is.null(obj@resourceId)) req = paste(req, obj@resourceId,sep="/")
-    return(req)
-  }
-  WIDUKIND@builder@handler$datastructure = function(obj){ 
-    req <- sprintf("%s/datastructure",obj@regUrl)
-    if(!is.null(obj@agencyId)){
-      req <- paste(req,obj@agencyId,sep="/")
-    }else{
-      req <- paste(req, "all",sep="/") #not supported by service
-    }
-    if(!is.null(obj@resourceId)) req <- paste(req, obj@resourceId, sep="/")
-    req <- paste0(req, "?references=children") #TODO to see later to have arg for this
-    return(req)
-  }
-  WIDUKIND@builder@handler$data = function(obj){
-    if(is.null(obj@flowRef)) stop("Missing flowRef value")
-    if(is.null(obj@agencyId)) obj@agencyId = "all"
-    if(is.null(obj@key)) obj@key = "all"
-    req <- sprintf("%s/%s/data/%s/%s",obj@repoUrl, obj@agencyId, obj@flowRef, obj@key)
-    
-    #DataQuery
-    #-> temporal extent (if any)
-    addParams = FALSE
-    if(!is.null(obj@start)){
-      req <- paste0(req, "?")
-      addParams = TRUE
-      req <- paste0(req, "startPeriod=", obj@start)
-    }
-    if(!is.null(obj@end)){
-      if(!addParams){
-        req <- paste0(req, "?")
-      }else{
-        req <- paste0(req, "&")
-      }
-      req <- paste0(req, "endPeriod=", obj@end) 
-    }
-    return(req)
-    
-  }
-  
   listOfProviders <- list(
     #international
-    ECB, ESTAT, IMF, OECD, UNICEF, UNSD, FAO, ILO_Legacy, ILO, UIS, UIS2, WBG_WITS, WB, PDH,
+    BIS, ECB, ESTAT, ESTAT_COMEXT, ESTAT_COMP, ESTAT_GROW, ESTAT_EMPL, IMF, IMF_DATA, OECD, UNICEF, CD2030, UNSD, ILO_Legacy, ILO, WBG_WITS, WB, PDH,
     #national
-    ABS, NBB, INSEE, INEGI, ISTAT, NOMIS, LSD, NCSI, STAT_EE, UKDS,
+    ABS, NBB, INSEE, INEGI, ISTAT_LEGACY, ISTAT, NOMIS, LSD, NCSI, BBK,
     #others
-    KNOEMA, WIDUKIND
+    KNOEMA
   )
 
   .rsdmx.options$providers <- new("SDMXServiceProviders", providers = listOfProviders)
@@ -541,7 +629,8 @@ setSDMXServiceProviders <- function(){ # nocov start
 #'   
 #' @seealso \link{getSDMXServiceProviders} \link{findSDMXServiceProvider}
 #'          \link{readSDMX}
-#'          
+#' @export
+#'         
 addSDMXServiceProvider <- function(provider){
   .rsdmx.options$providers <- new("SDMXServiceProviders",
                                   providers = c(slot(.rsdmx.options$providers, "providers"), provider)
@@ -566,7 +655,8 @@ addSDMXServiceProvider <- function(provider){
 #' 
 #' @seealso \link{addSDMXServiceProvider} \link{findSDMXServiceProvider}
 #'          \link{readSDMX}
-#'          
+#' @export
+#'        
 getSDMXServiceProviders <- function(){
   out <- .rsdmx.options$providers
   return(out)
@@ -596,7 +686,7 @@ getSDMXServiceProviders <- function(){
 #'   
 #' @seealso \link{getSDMXServiceProviders} \link{addSDMXServiceProvider}
 #'          \link{readSDMX}
-#'
+#' @export
 findSDMXServiceProvider <- function(agencyId){
   if(is.null(agencyId)) return(NULL)
   res <- unlist(lapply(slot(getSDMXServiceProviders(),"providers"),
